/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.domain.security.pkiclient;

import org.apache.commons.lang.builder.ToStringBuilder;

import se.vgregion.dao.domain.patterns.entity.AbstractEntity;

/**
 * Stores data about a type of e-legitimation. Existing e-legitimation is:
 * <ul>
 * <li>BankId</li>
 * <li>Nordea</li>
 * <li>Telia</li>
 * <li>SITSH</li>
 * </ul>
 * 
 * @author Anders Asplund - <a href="http://www.callistaenterprise.se">Callista Enterprise</a>
 */
public class ELegType extends AbstractEntity<String> {
    // Instances of this bean is created through spring configuration.

    private String name;
    private String description;
    private PkiClient pkiClient;

    /**
     * Constructs a new {@link ELegType}.
     * 
     * @param name
     *            the name of the e-legitimation
     * @param description
     *            a description of the e-legitimation
     * @param pkiClient
     *            the pki client to use when signing data with this e-legitimation
     */
    public ELegType(String name, String description, PkiClient pkiClient) {
        this.name = name;
        this.description = description;
        this.pkiClient = pkiClient;
    }

    @Override
    public String getId() {
        return name;
    }

    public String getName() {
        return name;
    }

    public String getDescription() {
        return description;
    }

    public PkiClient getPkiClient() {
        return pkiClient;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
