/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.domain.security.pkiclient;

import static se.vgregion.signera.signature._1.SignatureFormat.*;

import java.util.Locale;

import se.vgregion.signera.signature._1.SignatureFormat;

/**
 * Java 5 enumeration of Pki Clients.
 * 
 * @author Anders Asplund - <a href="http://www.callistaenterprise.se">Callista Enterprise</a>
 * 
 */
public enum PkiClient {

    /**
     * PKI Client used when signing with certificates supplied by Nordea.
     */
    NEXUS_PERSONAL_4(4, CMS),
    /**
     * PKI Client used when signing with certificates supplied by Telia and SITHS.
     */
    NETMAKER_NETID_4(5, CMS),
    /**
     * PKI Client used when signing with certificates supplied by BankId.
     */
    NEXUS_PERSONAL_4X(6, XMLDIGSIG);

    private int id;
    private SignatureFormat signatureFormat;

    private PkiClient(int id, SignatureFormat format) {
        this.id = id;
        this.signatureFormat = format;
    }

    public int getId() {
        return id;
    }

    public SignatureFormat getSignatureFormat() {
        return signatureFormat;
    }

    @Override
    public String toString() {
        return name().toLowerCase(new Locale("sv"));
    }
}